pyxmpp2.etree.ElementClass

Package pyxmpp2 :: Module etree :: Class ElementClass |
[hide private]

# Class ElementClass

Abstract class used to reference the `ElementTree.Element` object type of the selected Element Tree implementation.

Nested Classes | [hide private]
| __metaclass__ Metaclass for defining Abstract Base Classes (ABCs).

Instance Methods | [hide private]
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`

Class Methods | [hide private]
__subclasshook__(cls, other) Abstract classes can override this to customize issubclass(). |

Class Variables | [hide private]
| element_type = `None` hash(x)
| __abstractmethods__ = ``frozenset([``])``
| _abc_cache = `<_weakrefset.WeakSet object at 0x8591f2c>`
| _abc_negative_cache = `<_weakrefset.WeakSet object at 0x8596d8c>`
| _abc_negative_cache_version = `10`
| _abc_registry = `<_weakrefset.WeakSet object at 0x85913ac>`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __subclasshook__(cls, other) Class Method |
Abstract classes can override this to customize issubclass(). This is invoked early on by abc.ABCMeta.__subclasscheck__(). It should return True, False or NotImplemented. If it returns NotImplemented, the normal algorithm is used. Otherwise, it overrides the normal algorithm (and the outcome is cached). Overrides: object.__subclasshook__ (inherited documentation)